==> prestashop_1.4.0.2.zip: prestashop/modules/cashticket/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_330bf06fb43e715e5d03c9fd016df4cd'] = 'Le paiement n\'a pas encore été accepté : ';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_486cb12e1ec3c8b28b80a8eb9f2db2c0'] = 'Accepter le paiement';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_e9b3579d8e877bcd29ab436f2ef87cc8'] = 'Relacher le paiement';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Votre commande sur ';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'a bien été enregistrée.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_91675397c13245179e4bc959514fc2ca'] = 'Vous avez choisi de payer avec ';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2c987f462c2ab7fc63e061e871e6a97d'] = ' ';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_e6dc7945b557a1cd949bea92dd58963e'] = 'Votre commande va être expediée rapidement.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Pour toutes questions ou informations complémentaires, contactez notre';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'service client';
$_MODULE['<{cashticket}prestashop>cashticket_4512bbd48918c03027387a6c8e911342'] = 'CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_21d3d890383dc93343ce57c221ce5b3d'] = 'Accepter les paiements via CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_bed51f5187d4bf98e08f44d93f3098d9'] = 'Disposition crée. En attente du débit.';
$_MODULE['<{cashticket}prestashop>cashticket_894f0316a71ef67255369c82bf8a0e5b'] = 'L\'état de la disposition est invalide :';
$_MODULE['<{cashticket}prestashop>cashticket_e79174d4c28918ea3743a8386092cfab'] = 'Une erreur est survenue pendant le paiement :';
$_MODULE['<{cashticket}prestashop>cashticket_36ec50c0e914dd2fb48a1b27540512ce'] = 'Paiement accepté.';
$_MODULE['<{cashticket}prestashop>cashticket_d6ca44369efe062cec0c09f392465f55'] = 'Ce module requiert la librairie PHP cURL pour fonctionner correctement.';
$_MODULE['<{cashticket}prestashop>cashticket_fe9da2c5e2e153d2415b4cd5d91166a4'] = 'n\'a pas les droits en écriture.';
$_MODULE['<{cashticket}prestashop>cashticket_139cfa047b503ac5b9a6b4b1b03090ad'] = 'Ce module pour fonctionner correctement requiert la devise :';
$_MODULE['<{cashticket}prestashop>cashticket_ef5d34b04ab3b2eaaf7cb9d0f51267ed'] = 'Configurer chaque devise indépendament :';
$_MODULE['<{cashticket}prestashop>cashticket_f7e5c041093ae6902476457802835a1f'] = '(Le module de paiement ne sera pas affiché pour les clients qui utilisent une devise non configurée)';
$_MODULE['<{cashticket}prestashop>cashticket_7d3d009ac1b9d1e826a1a72c046ea635'] = 'Configuration en';
$_MODULE['<{cashticket}prestashop>cashticket_229a7ec501323b94db7ff3157a7623c9'] = 'ID Marchand';
$_MODULE['<{cashticket}prestashop>cashticket_845314022daaa8b665e718c4b51738aa'] = 'Keyring Certificat';
$_MODULE['<{cashticket}prestashop>cashticket_a01813de717585e9ac9458bbfc54485a'] = 'Keyring PW';
$_MODULE['<{cashticket}prestashop>cashticket_254f642527b45bc260048e30704edb39'] = 'Configuration';
$_MODULE['<{cashticket}prestashop>cashticket_0ba29c6a1afacf586b03a26162c72274'] = 'Environement';
$_MODULE['<{cashticket}prestashop>cashticket_1d5ad3d37f236c9eebda547690373bba'] = 'Business Type';
$_MODULE['<{cashticket}prestashop>cashticket_9eacfa0a89b48392a962b3fed24cd58e'] = 'Paiement immédiat';
$_MODULE['<{cashticket}prestashop>cashticket_c80a51a60c5ee43553c3881459b8f431'] = 'Mettre à jour la configuration';
$_MODULE['<{cashticket}prestashop>cashticket_1ed8d28fc462cdaba8f2ce9a400f2bfa'] = 'Vous devez fournir un certificat pour l\'ID marchand';
$_MODULE['<{cashticket}prestashop>cashticket_bbced877c13c763f0141ff906c8ed0e5'] = 'Fichier invalide';
$_MODULE['<{cashticket}prestashop>cashticket_97e5793f511c7930ab295997cb28553a'] = 'ID marchand invalide';
$_MODULE['<{cashticket}prestashop>cashticket_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mise à jour';
$_MODULE['<{cashticket}prestashop>cashticket_d139abab2541129dfae24c733635104c'] = 'Le fichier n\'a pas été téléchargé correctement';
$_MODULE['<{cashticket}prestashop>cashticket_d2bbf245e9591814fe994df3cae95964'] = 'Le fichier est vide';
$_MODULE['<{cashticket}prestashop>cashticket_ebbe99d835c79ead89db1b2b9e4fe70f'] = 'La transaction n\'a pu être initialisée du à des problèmes de connexions. Si le problème persiste, merci de nous contacter.';
$_MODULE['<{cashticket}prestashop>cashticket_99f6765a05b697eb78e8c2e5e228f2fc'] = 'Disposition consommée';
$_MODULE['<{cashticket}prestashop>cashticket_c3e260f43a99b6fd907538953fe700d0'] = 'Disposition relachée';
$_MODULE['<{cashticket}prestashop>cashticket_022492bc69b8205957d53b4166cd7090'] = 'Une erreur est survenue au moment de la relache.';
$_MODULE['<{cashticket}prestashop>cashticket_12f989194ad92e23c0eb3941db7f6720'] = 'Acceptez les paiements prépayés dans votre boutique en ligne. Cash-Ticket est une méthode de paiement simple et sécurisée pour l’internet. Cash-Ticket permet des paiements sans carte bancaires ni coordonnées bancaires personnelles. Tout ce qui est nécessaire pour payer dans une boutique en ligne est un code PIN de 16 chiffres. De cette façon les consommateurs peuvent réaliser des paiements en ligne sans carte de crédit ni même compte bancaire.';
$_MODULE['<{cashticket}prestashop>cashticket_75f5c89352ca1b7efc6bb03899ab9224'] = 'Une erreur est survenue. Consulter la partie \"Messages\" ci-dessous pour plus d\'informations';
$_MODULE['<{cashticket}prestashop>cashticket_a9ced76f2dd6907220fa95b3a136b04a'] = 'Montant incorrect';
$_MODULE['<{cashticket}prestashop>disposition-error_393988def796f78c4b673b90548f3afa'] = 'La disposition est dans un état invalide';
$_MODULE['<{cashticket}prestashop>disposition-error_5db89f2bf67f2c7dbd86cac101c3c1b8'] = '. Vous n\'êtes pas authorisé à récupérer le paiement.';
$_MODULE['<{cashticket}prestashop>payment_da9c72b9e543135f3f59e3c8ac68ef35'] = 'Payer avec';

==> prestashop_1.4.0.7.zip: prestashop/modules/cashticket/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_330bf06fb43e715e5d03c9fd016df4cd'] = 'Le paiement n\'a pas encore été accepté : ';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_486cb12e1ec3c8b28b80a8eb9f2db2c0'] = 'Accepter le paiement';
$_MODULE['<{cashticket}prestashop>cashticket-accept-payment_e9b3579d8e877bcd29ab436f2ef87cc8'] = 'Relacher le paiement';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2e2117b7c81aa9ea6931641ea2c6499f'] = 'Votre commande sur ';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_75fbf512d744977d62599cc3f0ae2bb4'] = 'a bien été enregistrée.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_91675397c13245179e4bc959514fc2ca'] = 'Vous avez choisi de payer avec ';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_2c987f462c2ab7fc63e061e871e6a97d'] = ' ';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_e6dc7945b557a1cd949bea92dd58963e'] = 'Votre commande va être expediée rapidement.';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_0db71da7150c27142eef9d22b843b4a9'] = 'Pour toutes questions ou informations complémentaires, contactez notre';
$_MODULE['<{cashticket}prestashop>cashticket-confirmation_64430ad2835be8ad60c59e7d44e4b0b1'] = 'service client';
$_MODULE['<{cashticket}prestashop>cashticket_4512bbd48918c03027387a6c8e911342'] = 'CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_21d3d890383dc93343ce57c221ce5b3d'] = 'Accepter les paiements via CashTicket';
$_MODULE['<{cashticket}prestashop>cashticket_bed51f5187d4bf98e08f44d93f3098d9'] = 'Disposition crée. En attente du débit.';
$_MODULE['<{cashticket}prestashop>cashticket_894f0316a71ef67255369c82bf8a0e5b'] = 'L\'état de la disposition est invalide :';
$_MODULE['<{cashticket}prestashop>cashticket_c1c25198721552ea8ddd963c7278d4ab'] = 'Une erreur est survenue pendant le paiement :';
$_MODULE['<{cashticket}prestashop>cashticket_36ec50c0e914dd2fb48a1b27540512ce'] = 'Paiement accepté.';
$_MODULE['<{cashticket}prestashop>cashticket_d6ca44369efe062cec0c09f392465f55'] = 'Ce module requiert la librairie PHP cURL pour fonctionner correctement.';
$_MODULE['<{cashticket}prestashop>cashticket_fe9da2c5e2e153d2415b4cd5d91166a4'] = 'n\'a pas les droits en écriture.';
$_MODULE['<{cashticket}prestashop>cashticket_139cfa047b503ac5b9a6b4b1b03090ad'] = 'Ce module pour fonctionner correctement requiert la devise :';
$_MODULE['<{cashticket}prestashop>cashticket_ef5d34b04ab3b2eaaf7cb9d0f51267ed'] = 'Configurer chaque devise indépendament :';
$_MODULE['<{cashticket}prestashop>cashticket_69a530f77bb82f704b9ff5e18bbdea6f'] = '(Le module de paiement ne sera pas affiché pour les clients qui utilisent une devise non configurée)';
$_MODULE['<{cashticket}prestashop>cashticket_7d3d009ac1b9d1e826a1a72c046ea635'] = 'Configuration en';
$_MODULE['<{cashticket}prestashop>cashticket_229a7ec501323b94db7ff3157a7623c9'] = 'ID Marchand';
$_MODULE['<{cashticket}prestashop>cashticket_845314022daaa8b665e718c4b51738aa'] = 'Keyring Certificat';
$_MODULE['<{cashticket}prestashop>cashticket_a01813de717585e9ac9458bbfc54485a'] = 'Keyring PW';
$_MODULE['<{cashticket}prestashop>cashticket_254f642527b45bc260048e30704edb39'] = 'Configuration';
$_MODULE['<{cashticket}prestashop>cashticket_0ba29c6a1afacf586b03a26162c72274'] = 'Environement';
$_MODULE['<{cashticket}prestashop>cashticket_1d5ad3d37f236c9eebda547690373bba'] = 'Business Type';
$_MODULE['<{cashticket}prestashop>cashticket_b024248d9fecf8c34f629e89a9fb93b4'] = 'Paiement immédiat';
$_MODULE['<{cashticket}prestashop>cashticket_c80a51a60c5ee43553c3881459b8f431'] = 'Mettre à jour la configuration';
$_MODULE['<{cashticket}prestashop>cashticket_86f28c996ee9075e9fc9a97dc8d5f254'] = 'Vous devez fournir un certificat pour l\'ID marchand';
$_MODULE['<{cashticket}prestashop>cashticket_bbced877c13c763f0141ff906c8ed0e5'] = 'Fichier invalide';
$_MODULE['<{cashticket}prestashop>cashticket_97e5793f511c7930ab295997cb28553a'] = 'ID marchand invalide';
$_MODULE['<{cashticket}prestashop>cashticket_c888438d14855d7d96a2724ee9c306bd'] = 'Configuration mise à jour';
$_MODULE['<{cashticket}prestashop>cashticket_a98658e7f6aa80803873db3a3e982f4d'] = 'Le fichier n\'a pas été téléchargé correctement';
$_MODULE['<{cashticket}prestashop>cashticket_d2bbf245e9591814fe994df3cae95964'] = 'Le fichier est vide';
$_MODULE['<{cashticket}prestashop>cashticket_ebbe99d835c79ead89db1b2b9e4fe70f'] = 'La transaction n\'a pu être initialisée du à des problèmes de connexions. Si le problème persiste, merci de nous contacter.';
$_MODULE['<{cashticket}prestashop>cashticket_99f6765a05b697eb78e8c2e5e228f2fc'] = 'Disposition consommée';
$_MODULE['<{cashticket}prestashop>cashticket_c3e260f43a99b6fd907538953fe700d0'] = 'Disposition relachée';
$_MODULE['<{cashticket}prestashop>cashticket_f6a62a622cbba2c1b8cd0be062deff96'] = 'Une erreur est survenue au moment de la relache.';
$_MODULE['<{cashticket}prestashop>cashticket_12f989194ad92e23c0eb3941db7f6720'] = 'Acceptez les paiements prépayés dans votre boutique en ligne. Cash-Ticket est une méthode de paiement simple et sécurisée pour l’internet. Cash-Ticket permet des paiements sans carte bancaires ni coordonnées bancaires personnelles. Tout ce qui est nécessaire pour payer dans une boutique en ligne est un code PIN de 16 chiffres. De cette façon les consommateurs peuvent réaliser des paiements en ligne sans carte de crédit ni même compte bancaire.';
$_MODULE['<{cashticket}prestashop>cashticket_d59048f21fd887ad520398ce677be586'] = 'En savoir plus';
$_MODULE['<{cashticket}prestashop>cashticket_ee363d108ef0c9c5a599d3afe04b9e32'] = 'Une erreur est survenue. Consulter la partie \"Messages\" ci-dessous pour plus d\'informations';
$_MODULE['<{cashticket}prestashop>cashticket_a9ced76f2dd6907220fa95b3a136b04a'] = 'Montant incorrect';
$_MODULE['<{cashticket}prestashop>disposition-error_393988def796f78c4b673b90548f3afa'] = 'La disposition est dans un état invalide';
$_MODULE['<{cashticket}prestashop>disposition-error_5db89f2bf67f2c7dbd86cac101c3c1b8'] = '. Vous n\'êtes pas authorisé à récupérer le paiement.';
$_MODULE['<{cashticket}prestashop>payment_da9c72b9e543135f3f59e3c8ac68ef35'] = 'Payer avec';
